@@ -7,6 +7,7 @@
 typedef struct {
     gboolean here;
     gboolean activate;
+    gboolean stop_int;
 } Options;
 
 static gpointer setup_func(ObParseInst *i, xmlDocPtr doc, xmlNodePtr node);
@@ -35,9 +36,12 @@ static gpointer setup_func(ObParseInst *i, xmlDocPtr doc, xmlNodePtr node)
     Options *o;
 
     o = g_new0(Options, 1);
+    o->stop_int = TRUE;
 
     if ((n = parse_find_node("here", node)))
         o->here = parse_bool(doc, n);
+    if ((n = parse_find_node("stopInteractive", node)))
+        o->stop_int = parse_bool(doc, n);
     return o;
 }
 
@@ -72,12 +76,18 @@ static gboolean run_func(ObActionsData *data, gpointer options)
             (data->context != OB_FRAME_CONTEXT_CLIENT &&
              data->context != OB_FRAME_CONTEXT_FRAME))
         {
+            if (o->stop_int)
+                actions_interactive_cancel_act();
+
             actions_client_move(data, TRUE);
             client_activate(data->client, TRUE, o->here,
                             o->activate, o->activate, TRUE);
             actions_client_move(data, FALSE);
         }
     } else if (data->context == OB_FRAME_CONTEXT_DESKTOP) {
+        if (o->stop_int)
+            actions_interactive_cancel_act();
+
         /* focus action on the root window. make keybindings work for this
            openbox instance, but don't focus any specific client */
         focus_nothing();
