@@ -4,7 +4,7 @@
 
 static gboolean run_func_toggle(ObActionsData *data, gpointer options);
 
-void action_omnipresent_startup()
+void action_omnipresent_startup(void)
 {
     actions_register("ToggleOmnipresent", NULL, NULL, run_func_toggle,
                      NULL, NULL);
