@@ -179,9 +179,11 @@ void prop_startup(void)
     CREATE(ob_wm_action_undecorate, "_OB_WM_ACTION_UNDECORATE");
     CREATE(ob_wm_state_undecorated, "_OB_WM_STATE_UNDECORATED");
     CREATE(ob_control, "_OB_CONTROL");
-    CREATE(ob_role, "_OB_ROLE");
-    CREATE(ob_name, "_OB_NAME");
-    CREATE(ob_class, "_OB_CLASS");
+    CREATE(ob_version, "_OB_VERSION");
+    CREATE(ob_app_role, "_OB_APP_ROLE");
+    CREATE(ob_app_name, "_OB_APP_NAME");
+    CREATE(ob_app_class, "_OB_APP_CLASS");
+    CREATE(ob_app_type, "_OB_APP_TYPE");
 }
 
 #include <X11/Xutil.h>
